<?php
/*
  French Chronopost Shipping module version 20081220 for ZenCart 1.3.8

  @package shippingMethod
  @copyright Copyright  2008 Philippe BLAIN <pblain@free.fr>.
  @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0

  ------------------------------------------------------------------------------
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  ------------------------------------------------------------------------------
  TARIFS CHRONOPOST EXPRESS AU 1er NOVEMBRE 2008, EN EUROS HT (TVA rcuprable),
  AU DPART DE FRANCE MTROPOLITAINE ET MONACO.

  Les colis confis doivent correspondre aux normes suivantes :
  Poids : infrieur ou gal  30 kg.
  Dimensions minimales : 22,9 cm x 16,2 cm
  Dimensions maximales : la somme de la longueur + 2 hauteurs + 2 largeurs
       ne doit pas excder 300 cm, la longueur ne devant pas excder 150 cm.

  Les envois destins aux pays de l'Union Europenne sont soumis  TVA.
  Des documents douaniers (facture en 5 exemplaires) doivent accompagner tous
  les envois de marchandises hors U.E. A libeller en anglais pour les pays
  non-francophones.

  Lexpditeur peut assurer le contenu de son colis dans la limite des plafonds
  maximum autoriss et moyennant le paiement de la prime correspondante.
  Il doit dclarer la valeur hors taxes du colis au recto du bordereau de
  transport,  compter du premier euro et payer la prime correspondante.

  ------------------------------------------------------------------------------
  USAGE :

  Ce module est prconfigur pour des KILOGRAMMES et des EUROS.
  Vrifiez que c'est le cas dans la configuration de votre boutique, sinon vous
  devrez transformer ici tous les tarifs et poids dans vos units.

  Vrifiez bien que vous avez entr le pays d'origine de la boutique expditrice.
  *** Admin->Configuration->Livraison. ***
  Ce module ne s'affichera qu'au dpart de FRANCE METROPOLITAINE et MONACO.

  Aprs copie des fichiers dans leur bon rpertoire; pour utiliser le module,
  allez dans l'admin d'osCommerce, cliquez sur le menu 'Modules', puis sur
  'Expdition'. Tous les modules d'expdition devraient apparaitre.
  Slectionnez 'Chronopost' et cliquez sur le bouton vert 'Installer'.
  La configuration par dfaut du module doit apparatre,  droite.
  Cliquez sur 'Editer' pour la modifier.

  Les tarifs et zones sont stocks dans des variables et non dans la BDD en
  raison de la limitation  255 caractres maximum des champs de table et du
  nombre de botes de saisie de paramtres qui deviendrait trop important dans
  l'administration du module. Toutes les modifications tarifaires ou de zone
  Chronopost doivent tre faites ici dans ce fichier, en dur. Cela vite aussi
  de perdre les paramtres ventuellement saisis en dsinstallant puis
  rinstallant ce module.

  Pour activer cette mthode d'expdition, vrifiez que 'Module Chronopost
  activ' est 'True'. Pour la dsactiver, positionnez sur 'False', puis 'Mise 
  jour'.

  Les zones Chronopost sont prconfigures et comprennent les codes ISO (2
  lettres majuscules) des pays appartenant  chaque zone, spars par une virgule
  (sans espace ou autre caractre de ponctuation). Vous pouvez modifier ces
  listes  votre guise pour restreindre les pays d'expdition (conseill). Pour
  la plupart des boutiques, vous n'entrerez pas la totalit des pays en raison
  de fraude de certains endroits. Un message indiquant l'impossibilit de livrer
  avec cette mthode s'affichera pour une commande  destination d'un pays
  non list.

  Pour chaque zone Chronopost, il y a un tarif d'expdition et un supplment
  correspondant. La mise  jour de ces tarifs s'effectue ici, en dur.
  Les tarifs fonctionnent sur le principe de tranches 'poids:cout' spars par
  une virgule.

  Si vous souhaitez avoir une tranche de 0  3 Kgs qui coutera 5.50 EUR HT
  d'expdition, vous devez la dfinir comme ceci : 3:5.5

  Exemple : tarif EUR HT vers Zone X pour des colis pesant entre 0 et 15 Kgs
  1:3.5,2:3.95,3:5.2,4:6.45,5:7.7,6:10.4,7:11.85,8:13.3,9:14.75,10:16.2,
  11:17.65,12:19.1,13:20.55,14:22,15:23.45

  La configuration de la boutique OsCommerce impose un poids maximum expdiable
  (Admin->Configuration->Expdition) au del duquel les colis sont fractionns.
  Le module vrifie que le poids de chaque colis ne dpasse pas 30 Kgs, sinon
  un message s'affichera.

  Pour l'expditon en dehors de Mtropole, un supplment HT est utilis pour les
  colis dont le poids dpasse le maximum du tarif correspondant (par 0.5 Kg
  supplmentaire).
  Notez qu'il est aussi possible de dsactiver entirement l'expdition
  vers l'International.

  Si vous voulez ajouter des frais fixes aux commandes par Chronopost,
  remplissez le champ 'Frais fixes Chronopost HT'.

  Si vous voulez restreindre l'expdition  une zone de taxation, remplissez le
  champ 'Expdier seulement vers cette zone de taxe'. Le module vrifie alors
  que le code ISO du pays de livraison est dans cette zone de taxation
  existante, sinon cette mthode d'expdition n'apparait pas pour la commande.

  ------------------------------------------------------------------------------
  AVERTISSEMENTS :

  Toutes les nouvelles zones Chronopost au 1er nov 2008 ont t implmentes.

  Il s'avre que le systme d'expdition d'OSC arrondit automatiquement
  le poids d'expdition jusqu' l'unit entire la plus proche.
  Ceci rend plus difficile de concevoir des tables prcises d'expdition.
  Si vous le voulez, vous pouvez modifier "shipping.php" pour vous dbarasser de
  l'arrondi.

  Le code a t dcompos en fonctions de manire  pouvoir facilement s'adapter
   des besoins particuliers au niveau des recommands, des options, ...
  Il suffit de rajouter des tests (ou de mettre en commentaires).

  ------------------------------------------------------------------------------
*/

  define ('MODULE_SHIPPING_CHRONOPOST_LIMIT', 30);         /* Poids maximum accept en Kgs */
  define ('MODULE_SHIPPING_CHRONOPOST_SUPP_CORSE', 16.6);  /* Supplment EUR HT pour CORSE */
  define ('MODULE_SHIPPING_CHRONOPOST_ENLEVEMENT', 11);    /* Enlvement sur demande */

  class chronopost {
  var $code, $title, $description, $sort_order, $icon, $tax_class, $international, $avec_enlevement, $avec_assurance, $enabled, $table, $quotes;

  /***** Class constructor *****/
  function chronopost() {
    global $order, $db, $template;

    $this->code            = 'chronopost';
    $this->title           = MODULE_SHIPPING_CHRONOPOST_TEXT_TITLE;
    $this->description     = MODULE_SHIPPING_CHRONOPOST_TEXT_DESCRIPTION;
    $this->sort_order      = MODULE_SHIPPING_CHRONOPOST_SORT_ORDER;
    $this->icon            = $template->get_template_dir('shipping_chronopost.gif', DIR_WS_TEMPLATE, $current_page_base,'images/icons') . '/' . 'shipping_chronopost.gif';
    $this->tax_class       = MODULE_SHIPPING_CHRONOPOST_TAX_CLASS;
    $this->international   = ((MODULE_SHIPPING_CHRONOPOST_INTERNATIONAL_ENABLED == 'True') ? true : false);
    $this->avec_enlevement = ((MODULE_SHIPPING_CHRONOPOST_AVEC_ENLEVEMENT == 'True') ? true : false);
    $this->avec_assurance  = ((MODULE_SHIPPING_CHRONOPOST_AVEC_ASSURANCE == 'True') ? true : false);

    /* Disable this module only when entire cart is free shipping */
    if (zen_get_shipping_enabled($this->code)) {
      $this->enabled = ((MODULE_SHIPPING_CHRONOPOST_STATUS == 'True') ? true : false);
    }

    /* Seulement au dpart de France mtropolitaine et Monaco */
    $shipping_country = $db->Execute("select countries_iso_code_2 from " . TABLE_COUNTRIES . " where countries_id = '" . SHIPPING_ORIGIN_COUNTRY . "'", '1');
    if (($shipping_country->fields['countries_iso_code_2'] != 'FR') && ($shipping_country->fields['countries_iso_code_2'] != 'FX') && ($shipping_country->fields['countries_iso_code_2'] != 'MC')) $this->enabled = false;

    /* DEFINITIONS DES ZONES TARIFAIRES CHRONOPOST */
    $this->table = array (
      array (
        'desc' => 'Zone tarifaire Domestique Chrono 13 (vers France mtropolitaine et Monaco)',
        'iso_codes' => 'FR,FX,MC',
        'tarif' => '2:26.10,5:31.8,10:39.25,15:45.7,20:52.15,25:58.6,30:65.05',
        'supp' => 0.0,
        'tarif_int' => '2:17.56,5:20.07,6:20.98,7:21.89,8:22.8,9:23.71,10:24.62',
        'supp_int' => 0.91
      ),

      array (
        'desc' => 'Zone tarifaire 1 (vers l\'Union Europenne)',
        'iso_codes' => 'BE,DE,LU,NL',
        'tarif' => '0.5:39.89,1:51.51,1.5:63.14,2:74.76,2.5:86.39,3:98.01,3.5:101.31,4:104.61,4.5:107.9,5:111.2,5.5:114.5,6:117.79,6.5:121.09,7:124.38,7.5:127.68,8:130.98,8.5:134.27,9:137.57,9.5:140.87,10:144.16',
        'supp' => 2.90,
        'tarif_int' => '0.5:39.03,1:43.41,1.5:48.44,2:53.47,2.5:58.5,3:63.53,3.5:68.56,4:73.59,4.5:78.62,5:83.66,5.5:88.69,6:93.72,6.5:98.75,7:103.78,7.5:108.81,8:113.84,8.5:118.87,9:123.9,9.5:128.93,10:133.97',
        'supp_int' => 2.93
      ),

      array (
        'desc' => 'Zone tarifaire 2 (vers l\'Union Europenne)',
        'iso_codes' => 'AT,DK,ES,ES,ES,FI,GB,GR,IE,IT,PT,SE',
        'tarif' => '0.5:41.39,1:53.59,1.5:65.79,2:77.98,2.5:90.18,3:102.37,3.5:105.9,4:109.43,4.5:112.96,5:116.49,5.5:120.02,6:123.55,6.5:127.08,7:130.61,7.5:134.14,8:137.67,8.5:141.21,9:144.74,9.5:148.27,10:151.8',
        'supp' => 3.1,
        'tarif_int' => '0.5:40.43,1:47.74,1.5:53.24,2:58.73,2.5:64.23,3:69.73,3.5:75.23,4:80.73,4.5:86.23,5:91.73,5.5:97.23,6:102.73,6.5:108.23,7:113.72,7.5:119.22,8:124.72,8.5:130.22,9:135.72,9.5:141.22,10:146.72',
        'supp_int' => 3.98
      ),

      array (
        'desc' => 'Zone tarifaire 3 (vers l\'Union Europenne)',
        'iso_codes' =>'BG,CY,CZ,EE,HU,LT,LV,MT,PL,RO,SI,SK',
        'tarif' => '0.5:78.4,1:95.5,1.5:112.6,2:129.7,2.5:146.8,3:163.8,3.5:178.7,4:193.6,4.5:208.4,5:223.3,5.5:235.8,6:248.3,6.5:260.8,7:273.4,7.5:285.9,8:298.4,8.5:310.9,9:323.4,9.5:336,10:348.5',
        'supp' => 8.9,
        'tarif_int' => '0.5:67,1:95.47,1.5:112.55,2:129.64,2.5:146.72,3:163.8,3.5:178.66,4:193.52,4.5:208.38,5:223.24,5.5:235.76,6:248.27,6.5:260.79,7:273.31,7.5:285.83,8:298.35,8.5:310.87,9:323.39,9.5:335.91,10:348.43',
        'supp_int' => 8.89
      ),

      array (
        'desc' => 'Zone tarifaire 4',
        'iso_codes' => 'AD,AL,AM,BA,BY,CH,FO,GE,GI,GS,HR,IC,IS,JE,LI,MD,ME,MK,NO,RS,RU,SM,TR,UA,VA',
        'tarif' => '0.5:56.72,1:71.51,1.5:86.29,2:101.07,2.5:115.85,3:130.63,3.5:135.95,4:141.26,4.5:146.57,5:151.89,5.5:157.2,6:162.51,6.5:167.83,7:173.14,7.5:178.45,8:183.77,8.5:189.08,9:194.39,9.5:199.71,10:205.02',
        'supp' => 4.8,
        'tarif_int' => '0.5:63.64,1:81.97,1.5:90.63,2:99.29,2.5:107.95,3:116.6,3.5:123.27,4:129.94,4.5:136.61,5:143.28,5.5:147.49,6:151.7,6.5:155.92,7:160.13,7.5:164.34,8:168.55,8.5:172.76,9:176.98,9.5:181.19,10:185.4',
        'supp_int' => 4.21
      ),

      array (
        'desc' => 'Zone tarifaire 5',
        'iso_codes' => 'AG,AI,AN,AR,AW,BB,BM,BO,BR,BS,BZ,CA,CL,CO,CR,CU,DM,DO,EC,GD,GL,GT,GY,HN,HT,JM,KN,KY,LC,MS,MX,NI,PA,PE,PR,PY,SR,SV,TC,TT,US,UY,VC,VE,VG,VI',
        'tarif' => '0.5:68.67,1:84.87,1.5:101.08,2:117.29,2.5:133.5,3:149.71,3.5:157.7,4:165.68,4.5:173.67,5:181.66,5.5:189.65,6:197.63,6.5:205.62,7:213.61,7.5:221.6,8:229.58,8.5:237.57,9:245.56,9.5:253.55,10:261.53',
        'supp' => 6.6,
        'tarif_int' => '0.5:73.01,1:93.82,1.5:103.65,2:113.48,2.5:123.3,3:133.13,3.5:136.88,4:140.62,4.5:144.36,5:148.11,5.5:152.91,6:157.7,6.5:162.5,7:167.3,7.5:172.09,8:176.89,8.5:181.69,9:186.48,9.5:191.28,10:196.08',
        'supp_int' => 7.61
      ),

      array (
        'desc' => 'Zone tarifaire 6',
        'iso_codes' => 'AE,AO,AZ,BF,BH,BI,BJ,BW,CD,CF,CG,CI,CM,CV,DJ,DZ,EG,ER,ET,GA,GH,GM,GN,GQ,GW,IL,IQ,IR,JO,KE,KM,KW,LB,LR,LS,LY,MA,MG,ML,MR,MU,MW,MZ,NA,NE,NG,OM,PS,QA,RW,SA,SC,SD,SL,SN,SO,ST,SY,SZ,TD,TG,TN,TZ,UG,YE,ZA,ZM,ZW',
        'tarif' =>  '0.5:82.33,1:101.97,1.5:121.6,2:141.23,2.5:160.87,3:180.5,3.5:194.32,4:208.15,4.5:221.97,5:235.79,5.5:249.62,6:263.44,6.5:277.26,7:291.08,7.5:304.91,8:318.73,8.5:332.55,9:346.38,9.5:360.2,10:374.02',
        'supp' => 11,
        'tarif_int' => '0.5:82.79,1:111.95,1.5:128.79,2:145.64,2.5:162.49,3:179.34,3.5:189.99,4:200.63,4.5:211.28,5:221.93,5.5:232.81,6:243.69,6.5:254.57,7:265.45,7.5:276.33,8:287.21,8.5:298.09,9:308.97,9.5:319.86,10:330.74',
        'supp_int' => 12.4
      ),

      array (
        'desc' => 'Zone tarifaire 7',
        'iso_codes' => 'AF,AS,AU,BD,BN,BT,CC,CK,CN,CX,FJ,FM,GU,HK,ID,IN,JP,KG,KH,KI,KR,KZ,LA,LK,MH,MM,MN,MO,MP,MV,MY,NF,NP,NR,NZ,PG,PH,PK,PW,SB,SG,TH,TJ,TL,TM,TO,TV,TW,UZ,VN,VU,WS',
        'tarif' =>  '0.5:83.61,1:103.73,1.5:123.85,2:143.97,2.5:164.09,3:184.21,3.5:198.99,4:213.77,4.5:228.55,5:243.33,5.5:258.1,6:272.88,6.5:287.66,7:302.44,7.5:317.22,8:332,8.5:346.78,9:361.56,9.5:376.34,10:391.11',
        'supp' => 11.6,
        'tarif_int' => '0.5:86.86,1:117.6,1.5:135.38,2:153.17,2.5:170.95,3:188.73,3.5:199.97,4:211.2,4.5:222.43,5:233.66,5.5:245.13,6:256.59,6.5:268.06,7:279.53,7.5:290.99,8:302.46,8.5:313.92,9:325.39,9.5:336.86,10:348.32',
        'supp_int' => 12.99
      ),

      array (
        'desc' => 'Zone tarifaire 8 (vers DOM)',
        'iso_codes' => 'GP,MI,MQ,RE',
        'tarif' => '0.5:68.64,1:83.89,1.5:99.13,2:114.37,2.5:129.61,3:144.86,3.5:149.98,4:155.11,4.5:160.23,5:165.36,5.5:170.49,6:175.61,6.5:180.74,7:185.86,7.5:190.99,8:196.12,8.5:201.24,9:206.37,9.5:211.49,10:216.62',
        'supp' => 5.01,
        'tarif_int' => '0.5:71.39,1:92.32,1.5:102.26,2:112.21,2.5:122.15,3:132.1,3.5:136.31,4:140.52,4.5:144.73,5:148.95,5.5:153.74,6:158.54,6.5:163.34,7:168.13,7.5:172.93,8:177.73,8.5:182.52,9:187.32,9.5:192.12,10:196.92',
        'supp_int' => 6.44
      ),

      array (
        'desc' => 'Zone tarifaire 9 (vers COM)',
        'iso_codes' => 'GF,NC,PF,PM,WF,YT',
        'tarif' => '0.5:89,1:111.12,1.5:133.23,2:155.35,2.5:177.47,3:199.58,3.5:218.23,4:236.87,4.5:255.51,5:274.16,5.5:292.8,6:311.45,6.5:330.09,7:348.73,7.5:367.38,8:386.02,8.5:404.67,9:423.31,9.5:441.95,10:460.6',
        'supp' => 13.6,
        'tarif_int' => '0.5:88.34,1:122.87,1.5:144.4,2:165.93,2.5:187.46,3:208.99,3.5:223.61,4:238.24,4.5:252.86,5:267.49,5.5:281.99,6:296.5,6.5:311.01,7:325.52,7.5:340.03,8:354.53,8.5:369.04,9:383.55,9.5:398.06,10:412.57',
        'supp_int' => 16.26
      )
    );

    $this->quotes = array();

    /* Vrification que le pays de livraison est dans la zone de taxation restreinte, sinon le module se dsactive. */
    if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_CHRONOPOST_TAX_ZONE > 0) ) {
      $check_flag = false;
      $check = $db->Execute("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_CHRONOPOST_TAX_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
      while (!$check->EOF) {
        if ($check->fields['zone_id'] < 1) {
          $check_flag = true;
          break;
        } elseif ($check->fields['zone_id'] == $order->delivery['zone_id']) {
          $check_flag = true;
          break;
        }
        $check->MoveNext();
      }
      if ($check_flag == false) $this->enabled = false;
    }
  }

  /***** Private methods *****/
  function _add_method($indice) {
    global $order, $shipping_num_boxes, $shipping_weight;

    if ($indice < 0) return;

    /* Calcul du cot d'1 colis (voir colis fractionns dans la classe 'shipping') */
     if (MODULE_SHIPPING_CHRONOPOST_TARIF_SELECTED == 'PDV') {
      $tarifs_array = split("[:,]", $this->table[$indice]["tarif"]);
      $cout_pour_05 = $this->table[$indice]["supp"];
    }
    else {
      $tarifs_array = split("[:,]", $this->table[$indice]["tarif_int"]);
      $cout_pour_05 = $this->table[$indice]["supp_int"];
    }
    $n = count($tarifs_array);
    $cost = -1;

    if ($indice == 0) {    /* Zone Domestique */
      $departement = substr($order->delivery['postcode'], 0, 2);
      for ($i = 0; $i < $n; $i += 2) {
        if ($shipping_weight <= $tarifs_array[$i]) {
          $cost = $tarifs_array[$i+1];
          if ($departement == '20' || $departement == '2A' || $departement == '2B')
            $cost += MODULE_SHIPPING_CHRONOPOST_SUPP_CORSE;
          break;
        }
      }
    }
    else {    /* International */
      /* Comparaison du poids d'1 colis avec le max dans table */
      if ($shipping_weight > $tarifs_array[$n-2]) { /* + supplment */
        $weight_sup = ceil(($shipping_weight - $tarifs_array[$n-2]) * 2);  /* par 0.5 kg supplmentaire */
        $cost = $tarifs_array[$n-1];
        $cost += $weight_sup * $cout_pour_05;
      }
      else { /* Dans le tableau tarif */
        for ($i = 0; $i < $n; $i += 2) {
          if ($shipping_weight <= $tarifs_array[$i]) {
            $cost = $tarifs_array[$i+1];
            break;
          }
        }
      }
    }

    if ($cost == -1) { /* Prix pas trouv */
      $this->quotes['error'] = MODULE_SHIPPING_CHRONOPOST_UNDEFINED_RATE;
      return;
    }
    else {
      if ($this->avec_enlevement)
        $cost += MODULE_SHIPPING_CHRONOPOST_ENLEVEMENT;
      $cost += MODULE_SHIPPING_CHRONOPOST_HANDLING;
    }

    /* Cot pour tous les colis */
    $cost *= $shipping_num_boxes;

    /* Assurance du bien transport */
    if ($this->avec_assurance) {
      $total = $_SESSION['cart']->show_total();
      if ($total < 500) $assurance = 2.51;
      elseif ($total < 1000) $assurance = 5.02;
      elseif ($total < 2000) $assurance = 8.36;
      elseif ($total < 5000) $assurance = 20.9;
      else $assurance = 0;

      $cost += $assurance;
    }

    /* Stockage paramtres */
    $this->quotes['methods'][] = array(
      'id'    => $this->code,
      'title' => $shipping_num_boxes . ' x ' . $shipping_weight . MODULE_SHIPPING_CHRONOPOST_TEXT_UNITS . $order->delivery['country']['title'],
      'cost'  => $cost);

    return;
  }

  /***** Public methods *****/
  function quote($method = '') {
    global $order, $shipping_weight, $shipping_num_boxes;

    $this->quotes = array(
      'id' => $this->code,
      'module' => MODULE_SHIPPING_CHRONOPOST_TEXT_TITLE,
      'methods' => array());

    if (zen_not_null($this->icon)) $this->quotes['icon'] = zen_image($this->icon, $this->title);

    if ($shipping_weight > MODULE_SHIPPING_CHRONOPOST_LIMIT) {
      $this->quotes['error'] = $shipping_num_boxes . ' x ' . $shipping_weight . MODULE_SHIPPING_CHRONOPOST_TOO_HEAVY;
      return $this->quotes;
    }

    /* Returns the tax rate for a zone / class -  TABLES: tax_rates, zones_to_geo_zones */
    if ($this->tax_class > 0)
      $this->quotes['tax'] = zen_get_tax_rate($this->tax_class, $order->delivery['country']['id'], $order->delivery['zone_id']);

    $destination = $order->delivery['country']['iso_code_2'];  /* Pays de destination */

    /* Correction selon code postal du destinataire en cas mauvaise saisie utilisateur pour DOM,TOM,CT */
    if ($destination == 'FR' or $destination == 'FX') {
      $dest3 = substr(trim($order->delivery['postcode']), 0, 3);
      if ($dest3 == '971') $destination = 'GP';
      elseif ($dest3 == '972') $destination = 'MQ';
      elseif ($dest3 == '973') $destination = 'GF';
      elseif ($dest3 == '974') $destination = 'RE';
      elseif ($dest3 == '975') $destination = 'PM';
      elseif ($dest3 == '976') $destination = 'YT';
      elseif ($dest3 == '984') $destination = 'TF';
      elseif ($dest3 == '986') $destination = 'WF';
      elseif ($dest3 == '987') $destination = 'PF';
      elseif ($dest3 == '988') $destination = 'NC';
    }

    /* Recherche zone Chronopost du pays de destination */
    $dest_zone = -1;
    for ($i = 0; $i < count($this->table); $i++) {
      $iso_codes_array = split("[,]", $this->table[$i]["iso_codes"]);
      if (in_array($destination, $iso_codes_array)) {
        $dest_zone = $i;
        break;
      }
    }
    if ($dest_zone < 0) {
      $this->quotes['error'] = MODULE_SHIPPING_CHRONOPOST_INVALID_ZONE;
      return $this->quotes;
    }

    switch ($destination) {
      /* Mtropole */
    case 'FR' :
    case 'FX' :
    case 'MC' :
      /* DOM */
    case 'GP' :
    case 'MQ' :
    case 'RE' :
    case 'GF' :
      /* TOM */
    case 'NC' :
    case 'PF' :
    case 'WF' :
    case 'TF' :
      /* Collectivits Territoriales */
    case 'YT' :
    case 'PM' :
      $this->_add_method($dest_zone);
      break;

    default :
      /* Hors de France */
      if ($this->international) {
        $this->_add_method($dest_zone);
      }
      else $this->quotes['error'] = MODULE_SHIPPING_CHRONOPOST_INVALID_COUNTRY;
      break;
    } /* end switch */

    return $this->quotes;
  }

  /* Active - Dsactive */
  function check() {
    global $db;

    if (!isset($this->_check)) {
      $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_CHRONOPOST_STATUS'");
      $this->_check = $check_query->RecordCount();
    }
    return $this->_check;
  }

  /* Constantes stockes dans BDD */
  function install() {
    global $db;

    /*Activation du module */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Module Chronopost activ ?', 'MODULE_SHIPPING_CHRONOPOST_STATUS', 'True', 'Voulez-vous activer l\'expdition par Chronopost ?', '6', '0','zen_cfg_select_option(array(\'True\', \'False\'), ', now())");

    /* Tarif point de vente ou internet */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Tarif \'Point de Vente\' ou \'Internet\' ?', 'MODULE_SHIPPING_CHRONOPOST_TARIF_SELECTED', 'PDV', 'Appliquer le tarif public ou exclusif internet (moins cher) ?', '6', '0','zen_cfg_select_option(array(\'PDV\', \'Internet\'), ', now())");

    /* Ajouter des frais fixes HT ? */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Frais fixes Chronopost HT', 'MODULE_SHIPPING_CHRONOPOST_HANDLING', '0', 'Les frais fixes HT d\'expdition par Chronopost (emballage, ...)', '6', '0', now())");

    /* Appliquer une taxe sur frais d'expdition ? */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Classe de taxe sur frais d\'expdition', 'MODULE_SHIPPING_CHRONOPOST_TAX_CLASS', '0', 'Appliquer le taux de taxe suivant sur les frais d\'expdition', '6', '0', 'zen_get_tax_class_title', 'zen_cfg_pull_down_tax_classes(', now())");

    /* Expdier seulement vers une zone de taxe ? */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Expdier seulement vers cette zone de taxe', 'MODULE_SHIPPING_CHRONOPOST_TAX_ZONE', '0', 'Si une zone de taxe est slectionne, ce mode de livraison fonctionnera uniquement pour la zone choisie.', '6', '0', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(', now())");

    /* Slection des affichages */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Autoriser livraisons  l\'International ?', 'MODULE_SHIPPING_CHRONOPOST_INTERNATIONAL_ENABLED', 'False', 'Voulez-vous autoriser les livraisons  l\'International ?', '6', '0','zen_cfg_select_option(array(\'True\', \'False\'), ', now())");

    /* Enlvement sur demande */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Enlvement sur demande ?', 'MODULE_SHIPPING_CHRONOPOST_AVEC_ENLEVEMENT', 'False', 'Voulez-vous ajouter l\'enlvement au prix du transport ?', '6', '0','zen_cfg_select_option(array(\'True\', \'False\'), ', now())");

    /* Avec assurance ? */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Ajouter assurance ?', 'MODULE_SHIPPING_CHRONOPOST_AVEC_ASSURANCE', 'False', 'Voulez-vous faire payer une prime d\'assurance selon la valeur dclare ?', '6', '0','zen_cfg_select_option(array(\'True\', \'False\'), ', now())");

    /* Ordre d'affichage */
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre de Tri', 'MODULE_SHIPPING_CHRONOPOST_SORT_ORDER', '0', 'Ordre de tri pour l\'affichage.', '6', '0', now())");

   }

  /* Effacement de toutes les cls dans la BDD */
  function remove() {
    global $db;

    $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
  }

  /* Retourne un tableau des cls */
  function keys() {
    return array(
      'MODULE_SHIPPING_CHRONOPOST_STATUS',
      'MODULE_SHIPPING_CHRONOPOST_TARIF_SELECTED',
      'MODULE_SHIPPING_CHRONOPOST_HANDLING',
      'MODULE_SHIPPING_CHRONOPOST_TAX_CLASS',
      'MODULE_SHIPPING_CHRONOPOST_TAX_ZONE',
      'MODULE_SHIPPING_CHRONOPOST_INTERNATIONAL_ENABLED',
      'MODULE_SHIPPING_CHRONOPOST_AVEC_ENLEVEMENT',
      'MODULE_SHIPPING_CHRONOPOST_AVEC_ASSURANCE',
      'MODULE_SHIPPING_CHRONOPOST_SORT_ORDER');
  }
}
?>
